(()=>{var t={52755:(t,e,r)=>{"use strict";r.d(e,{X2:()=>i});const o=/([^/]+$)/,n=t=>{let e="";e=0===t.indexOf("https")?new URL(t):new URL("https:"+t);const r=e.pathname.match(o);if(r)return e.origin+"/embed/"+r[1]},i=t=>{const e=document.getElementById(t),r=e.querySelector("a"),o={width:"100%",height:"200",frameborder:"0",title:r.getAttribute("title"),src:n(r.href)},i=document.createElement("iframe");window.addEventListener("message",(t=>{t.origin.startsWith("https://nextdoor")&&t.source===i.contentWindow&&i.setAttribute("height",t.data.height+"px")})),Object.keys(o).forEach((t=>i.setAttribute(t,o[t]))),e.replaceChild(i,r)}},79366:(t,e,r)=>{"object"==typeof window&&window.Jetpack_Block_Assets_Base_Url&&(r.p=window.Jetpack_Block_Assets_Base_Url)}},e={};function r(o){var n=e[o];if(void 0!==n)return n.exports;var i=e[o]={exports:{}};return t[o](i,i.exports,r),i.exports}r.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return r.d(e,{a:e}),e},r.d=(t,e)=>{for(var o in e)r.o(e,o)&&!r.o(t,o)&&Object.defineProperty(t,o,{enumerable:!0,get:e[o]})},r.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(t){if("object"==typeof window)return window}}(),r.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e),(()=>{var t;r.g.importScripts&&(t=r.g.location+"");var e=r.g.document;if(!t&&e&&(e.currentScript&&"SCRIPT"===e.currentScript.tagName.toUpperCase()&&(t=e.currentScript.src),!t)){var o=e.getElementsByTagName("script");if(o.length)for(var n=o.length-1;n>-1&&(!t||!/^http(s?):/.test(t));)t=o[n--].src}if(!t)throw new Error("Automatic publicPath is not supported in this browser");t=t.replace(/#.*$/,"").replace(/\?.*$/,"").replace(/\/[^\/]+$/,"/"),r.p=t+"../"})(),(()=>{"use strict";r(79366)})(),(()=>{"use strict";var t=r(52755);document.addEventListener("DOMContentLoaded",(()=>{document.querySelectorAll("figure").forEach((e=>{e.id.startsWith("nextdoor-block")&&(0,t.X2)(e.id)}))}))})()})();